import requests
from urllib.parse import quote_plus

headers = {
    'Host': 'api.genius.com',
    'Accept': '*/*',
    'Content-Type': 'application/json',
    'X-Genius-iOS-Version': '6.0.6',
    'User-Agent': 'Genius/825 CFNetwork/1121.2.2 Darwin/19.2.0',
}


def lyrics(query):
    search_resp = _search_multi(query)
    song_id = _song_from_search(search_resp)
    song_resp = _songs(song_id)
    return _clean_lyrics(_lyrics_from_song(song_resp))


def _search_multi(query, per_page=3):
    params = (
        ('q', query),
        ('per_page', per_page),
    )
    response = requests.get('https://api.genius.com/search/multi',
                            headers=headers,
                            params=params)
    return response.json()


def _songs(song_id, text_format='plain'):
    params = (('text_format', text_format))
    response = requests.get('https://api.genius.com/songs/{}'.format(song_id),
                            headers=headers,
                            params=params)
    return response.json()


def _song_from_search(result):
    for section in result['response']['sections']:
        if section['type'] != 'top_hit':
            continue
        for hit in section['hits']:
            if hit['type'] != 'song':
                continue
            return hit['result']['id']


def _lyrics_from_song(result):
    return result['response']['song']['lyrics']['plain']


def _clean_lyrics(lyrics):
    lines = []
    for line in lyrics.split('\n'):
        line = line.strip()
        if line.startswith('[') and line.endswith(']'):
            continue
        if line == '':
            continue
        lines.append(line)
    return '\n'.join(lines)


import requests
from bs4 import BeautifulSoup
from urllib.parse import quote_plus

headers = {
    'User-Agent':
    'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/78.0.3904.108 Safari/537.36'
}


def lyrics(query):
    query = quote_plus(query)
    search_url = 'https://www.google.com/search?q={}'.format(query)
    res = requests.get(search_url, headers=headers)
    soup = BeautifulSoup(res.text, 'html.parser')
    el = soup.find('g-expandable-content', {'data-eb': '0'})
    if not el:
        return
    els = el.find_all('span', {'jsname': 'YS01Ge'})
    lines = []
    for el in els:
        lines.append(el.get_text())
    lyrics = '\n'.join(lines)
    return lyrics


from setuptools import setup, find_packages
from os import path

this_directory = path.abspath(path.dirname(__file__))
readme_filename = path.join(this_directory, 'README.md')

with open(readme_filename, encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='lyr',
    version='0.0.2',
    description='lyrics providers',
    long_description=long_description,
    long_description_content_type='text/markdown',
    author_email='youka.club@gmail.com',
    url='https://github.com/youkaclub/lyr',
    packages=find_packages(),
    include_package_data=True,
    zip_safe=False,
    install_requires=[
        'bs4==0.0.1',
        'requests==2.21.0',
    ]
)